==> kdepim-3.2.3.tar.bz2: kdepim-3.2.3/kontact/plugins/knotes/summarywidget.h <==
/*
    This file is part of Kontact.
    Copyright (c) 2003 Tobias Koenig <tokoe@kde.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

    As a special exception, permission is given to link this program
    with any edition of Qt, and distribute the resulting executable,
    without including the source code for Qt in the source distribution.
*/

#ifndef SUMMARYWIDGET_H
#define SUMMARYWIDGET_H

#include "summary.h"

#include <qmap.h>
#include <qptrlist.h>
#include <qwidget.h>

#include <libkcal/calendarlocal.h>

typedef QMap<QString, QString> NotesMap;

class QGridLayout;
class QLabel;

class SummaryWidget : public Kontact::Summary
{
  Q_OBJECT

  public:
    SummaryWidget( QWidget *parent, const char *name = 0 );

  protected:
    bool ensureKNotesRunning();

  protected slots:
    void urlClicked( const QString& );
    void updateView();

  private:
    KCal::CalendarLocal *mICal;
    KCal::Journal::List mNotes;

    QVBoxLayout *mMainLayout;
    QVBoxLayout *mLayout;

    QPtrList<QLabel> mLabels;
    NotesMap mNotesMap;
};

#endif

==> kdepim-3.3.2.tar.bz2: kdepim-3.3.2/kontact/plugins/knotes/summarywidget.h <==
/*
    This file is part of Kontact.
    Copyright (c) 2003 Tobias Koenig <tokoe@kde.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

    As a special exception, permission is given to link this program
    with any edition of Qt, and distribute the resulting executable,
    without including the source code for Qt in the source distribution.
*/

#ifndef SUMMARYWIDGET_H
#define SUMMARYWIDGET_H

#include "summary.h"

#include <qmap.h>
#include <qptrlist.h>
#include <qwidget.h>

#include <libkcal/resourcelocal.h>
#include <libkcal/calendarresources.h>

class QGridLayout;
class QLabel;

namespace Kontact {
class Plugin;
}

class SummaryWidget : public Kontact::Summary
{
  Q_OBJECT

  public:
    SummaryWidget( Kontact::Plugin *plugin, QWidget *parent, const char *name = 0 );

    void updateSummary( bool force = false ) { Q_UNUSED( force ); updateView(); }

  protected:
    bool ensureKNotesRunning();

  protected slots:
    void urlClicked( const QString& );
    void updateView();
    void addNote( KCal::Journal* );
    void removeNote( KCal::Journal* );

  private:
    KCal::CalendarLocal *mCalendar;
    KCal::Journal::List mNotes;

    QVBoxLayout *mMainLayout;
    QVBoxLayout *mLayout;

    QPtrList<QLabel> mLabels;
    Kontact::Plugin *mPlugin;
};

#endif
